<?php
if ( ! function_exists( 'biography_sanitize_number_range' ) ) :
    /**
     * Function to sanitize number range
     *
     * @access public
     * @since 1.1
     *
     * @param $biography_input
     * @param $biography_setting
     * @return int || float || numeric value
     *
     */
    function biography_sanitize_number_range( $biography_input, $biography_setting ) {

        // Ensure input is an absolute integer.
        $biography_input = absint( $biography_input );

        // Get the input attributes associated with the setting.
        $atts = $biography_setting->manager->get_control( $biography_setting->id )->input_attrs;

        // Get minimum number in the range.
        $min = ( isset( $atts['min'] ) ? $atts['min'] : $biography_input );

        // Get maximum number in the range.
        $max = ( isset( $atts['max'] ) ? $atts['max'] : $biography_input );

        // Get step.
        $step = ( isset( $atts['step'] ) ? $atts['step'] : 1 );

        // If the number is within the valid range, return it; otherwise, return the default
        return ( $min <= $biography_input && $biography_input <= $max && is_int( $biography_input / $step ) ? $biography_input : $biography_setting->default );
    }

endif;