<?php
/**
* Returns word count of the sentences.
*
* @since @since Biography 1.0.0
*/
if ( ! function_exists( 'biography_words_count' ) ) :
/**
 * Trim content to word $length specified
 *
 * @param  integer $length            number of words
 *
 * @param  string  $biography_content content to be trimmed
 *
 * @return string                     trimmed content
 *
 */
function biography_words_count( $length = 25, $biography_content = null, $after_content_dots ) {
	$length = absint( $length );

    if ( '' != $biography_content ) {

        $biography_content = strip_shortcodes( $biography_content );
        $biography_content = str_replace( ']]>', ']]&gt;', $biography_content );
        // $biography_content = strip_tags($biography_content, wpse_allowedtags());

        //Set the excerpt word count and only break after sentence is complete.
        $excerpt_word_count = $length;
        $excerpt_length = apply_filters( 'excerpt_length', $excerpt_word_count );
        $tokens = array();
        $excerptOutput = '';
        $count = 0;

        // Divide the string into tokens; HTML tags, or words, followed by any whitespace
        preg_match_all( '/(<[^>]+>|[^<>\s]+)\s*/u', $biography_content, $tokens );

        foreach ( $tokens[0] as $token ) {

            if ( $count >= $excerpt_word_count && preg_match('/[\,\;\?\.\!]\s*$/uS', $token ) ) {
                // Limit reached, continue until , ; ? . or ! occur at the end
                $excerptOutput .= trim( $token );
                break;
            }

            // Add words to complete sentence
            $count++;

            // Append what's left of the token
            $excerptOutput .= $token;
        }

        $biography_content = trim( force_balance_tags( $excerptOutput ) );

        if ( $after_content_dots == true ) {
            // After the content
            $biography_content .= '...';
        }
       

        return $biography_content;
    }

    return apply_filters( 'biography_words_count', $biography_content );
}
endif;

if ( ! function_exists( 'biography_words_count_widget' ) ) :
    function biography_words_count_widget( $length = 25, $biography_content = null ) {
        $length = absint( $length );
        $source_content = preg_replace( '`\[[^\]]*\]`', '', $biography_content );
        $trimmed_content = wp_trim_words( $source_content, $length, '...' );
        return $trimmed_content;
    }
endif;